@@ -1,15 +1,25 @@
 import sys
 import importlib
+from types import ModuleType
+from typing import Type, Callable, Any
 
 
 def qualname(obj):
     return obj.__module__ + "." + obj.__name__
 
 
-def import_qualname(qualname):
+def import_module(module_name: str, reload: bool = False) -> ModuleType:
+    already_loaded = module_name in sys.modules
+    mod = importlib.import_module(module_name)
+    if already_loaded and reload:
+        return importlib.reload(mod)
+    return mod
+
+
+def import_qualname(qualname, reload: bool = False) -> Any:
     if not isinstance(qualname, str):
         raise TypeError(qualname, type(qualname))
-    module_name, dot, obj_name = qualname.rpartition(".")
+    module_name, _, obj_name = qualname.rpartition(".")
     if not module_name:
         raise ImportError(f"cannot import {qualname}")
 
@@ -18,7 +28,7 @@ def import_qualname(qualname):
         # through a python console script
         sys.path.append("")
 
-    module = importlib.import_module(module_name)
+    module = import_module(module_name, reload=reload)
 
     try:
         return getattr(module, obj_name)
@@ -26,13 +36,13 @@ def import_qualname(qualname):
         raise ImportError(f"cannot import {obj_name} from {module_name}")
 
 
-def import_method(qualname):
-    method = import_qualname(qualname)
+def import_method(qualname, reload: bool = False) -> Callable:
+    method = import_qualname(qualname, reload=reload)
     if not callable(method):
         raise RuntimeError(repr(qualname) + " is not callable")
     return method
 
 
-def instantiate_class(class_name: str, *args, **kwargs):
+def instantiate_class(class_name: str, *args, **kwargs) -> Type:
     cls = import_qualname(class_name)
     return cls(*args, **kwargs)
